#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['pycountry_un']

package_data = \
{'': ['*'], 'pycountry_un': ['databases/*']}

install_requires = \
['pycountry~=19.8']

extras_require = \
{'dev': ['black'], 'test': ['coverage~=5.0', 'pytest~=5.0']}

setup(name='pycountry-un',
      version='0.1.0',
      description="Provide lists in the United Nation's World Economic Situation and Prospects",
      author='Fábio Macêdo Mendes',
      author_email='fabiomacedomendes@gmail.com',
      url='http://github.com/fabiommendes/covid-19',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
     )
